<?php
class Menu_Item_Custom_Fields_Example {

	/**
	 * Holds our custom fields
	 *
	 * @var    array
	 * @access protected
	 * @since  Menu_Item_Custom_Fields_Example 0.2.0
	 */
	protected static $fields = array();


	/**
	 * Initialize plugin
	 */
	public static function init() {
		add_action( 'wp_nav_menu_item_custom_fields', array( __CLASS__, '_fields' ), 10, 4 );
		add_action( 'wp_update_nav_menu_item', array( __CLASS__, '_save' ), 10, 3 );
		add_filter( 'manage_nav-menus_columns', array( __CLASS__, '_columns' ), 99 );

		self::$fields = array(
			'type_menu_for_display' => 'نحوه نمایش این منو (این آیتم رو در سطح اول نیاز هست انتخاب کنید)',
			'background_mega_menu' => 'عکس بک گراند سطح دوم مگامنو (این آیتم رو در سطح دوم مگامنو درج کنید)',
		);
	}


	/**
	 * Save custom field value
	 *
	 * @wp_hook action wp_update_nav_menu_item
	 *
	 * @param int   $menu_id         Nav menu ID
	 * @param int   $menu_item_db_id Menu item ID
	 * @param array $menu_item_args  Menu item data
	 */
	public static function _save( $menu_id, $menu_item_db_id, $menu_item_args ) {
		if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
			return;
		}

		check_admin_referer( 'update-nav_menu', 'update-nav-menu-nonce' );

		foreach ( self::$fields as $_key => $label ) {
			$key = sprintf( 'menu-item-%s', $_key );

			// Sanitize
			if ( ! empty( $_POST[ $key ][ $menu_item_db_id ] ) ) {
				// Do some checks here...
				$value = $_POST[ $key ][ $menu_item_db_id ];
			} else {
				$value = null;
			}

			// Update
			if ( ! is_null( $value ) ) {
				update_post_meta( $menu_item_db_id, $key, $value );
			} else {
				delete_post_meta( $menu_item_db_id, $key );
			}
		}
	}


	/**
	 * Print field
	 *
	 * @param object $item  Menu item data object.
	 * @param int    $depth  Depth of menu item. Used for padding.
	 * @param array  $args  Menu item args.
	 * @param int    $id    Nav menu ID.
	 *
	 * @return string Form fields
	 */
	public static function _fields( $id, $item, $depth, $args ) {
		$counter = 1;
		foreach ( self::$fields as $_key => $label ) :
			$key   = sprintf( 'menu-item-%s', $_key );
			$id    = sprintf( 'edit-%s-%s', $key, $item->ID );
			$name  = sprintf( '%s[%s]', $key, $item->ID );
			$value = get_post_meta( $item->ID, $key, true );
			$class = sprintf( 'field-%s', $_key );

			if ( $counter == 1 ){
				$counter++;
				echo '<label style="display:block;padding:26px 0;overflow: hidden;width: 100%;">'.$label.'<br>';
				echo '<select id="'.$id.'" name="'.$name.'" class="'.$class.'">';
					echo '<option value="menu_absahri" ';
					if ( $value == 'menu_absahri' ) echo ' selected ';
					echo '>منوی آبشاری</option>';
					echo '<option value="megamenu_by_tree_level" ';
					if ( $value == 'megamenu_by_tree_level' ) echo ' selected ';
					echo '>مگامنوی چهار سطحی مانند دیجی کالا</option>';
				echo '</select></label>';
			} else {
				echo '<label style="display:block;padding:26px 0;overflow: hidden;width: 100%;">'.$label.'<br>';
					echo '<input value="'.$value.'" type="text" id="'.$id.'" name="'.$name.'" class="'.$class.'" >';
				echo '</label>';
			}
			
			
			
		endforeach;
	}


	/**
	 * Add our fields to the screen options toggle
	 *
	 * @param array $columns Menu item columns
	 * @return array
	 */
	public static function _columns( $columns ) {
		$columns = array_merge( $columns, self::$fields );

		return $columns;
	}
}
Menu_Item_Custom_Fields_Example::init();
