<?php
/**
 * Initialize the custom Theme Options.
 */
add_action( 'init', 'custom_theme_options' );

/**
 * Build the custom settings & update OptionTree.
 *
 * @return    void
 * @since     2.0
 */
function custom_theme_options() {

  /* OptionTree is not loaded yet, or this is not an admin request */
  if ( ! function_exists( 'ot_settings_id' ) || ! is_admin() )
    return false;

  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( ot_settings_id(), array() );
  
  /**
   * Custom settings array that will eventually be 
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array( 
    'contextual_help' => array( 
      'content'       => array( 
        array(
          'id'        => 'option_types_help',
          'title'     => 'تنظیمات',
          'content'   => '<p>' . __( 'Help content goes here!', 'theme-text-domain' ) . '</p>'
        )
      ),
      'sidebar'       => '<p>' . __( 'Sidebar content goes here!', 'theme-text-domain' ) . '</p>'
    ),
    'settings'        => array( 
      array(
        'id'          => 'favicon',
        'label'       => 'فیو آیکون',
        'desc'        => 'برای اینکه وب سایت شما فیو آیکون داشته باشد یک عکس با عرض و ارتفاع 16 پیکسل آپلود نمائید یا آدرس مستقیم آن را در اینجا درج نمائید.',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'responsive',
        'label'       => 'حالت نمایش موبایلی',
        'desc'        => 'اگر میخواهید حالت نمایش موبایلی رو فعال کنید این گزینه رو بر روی on بذارید.',
        'std'         => '',
        'type'        => 'on-off',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'color_button',
        'label'       => 'بک گراند دکمه های ووکامرس',
        'desc'        => 'در صورت تمایل بک گراند دکمه های افزودن به سبد خرید و مابقی دکمه های ووکامرس رو انتخاب کنید.',
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
 	 array( 
        'id'          => 'ConvertNumberToPersion',
        'label'       => 'تبدیل تمامی اعداد انگلیسی به فارسی',
        'desc'        => 'در صورتی که مایل هستید اعداد انگلیسی سایت به اعداد فارسی تبدیل شود این گزینه را فعال نمائید.',
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'general',
      ),	  
      array(
        'id'          => 'defult_img',
        'label'       => 'تصویر پیش فرض',
        'desc'        => 'یک عکس با عرض و ارتفاع 1024*1024 پیکسل آپلود نمائید. این تصویر هنگامی که هر کدام از پست ها یا برگه های شما دارای تصویر شاخص نباشند جایگزین تصویر شاخص خواهد شد. این تصویر میتواند لوگوی وب سایت شما باشد.',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	   array(
        'id'          => 'background_login',
        'label'       => 'تصویر بک گراند صفحه لاگین وردپرس',
        'desc'        => 'یک عکس به دلخواه خود میتوانید در این قسمت آپلود نموده تا در بک گراند صفحه لاگین وردپرس شما نمایش داده شود.',
        'std'         =>  get_bloginfo('template_url').'/images/a.jpg',
        'type'        => 'upload',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'analytics',
        'label'       => 'گوگل آنالیتکز',
        'desc'        => 'کد سایت گوگل آنالیتیکز را در این باکس درج نمائید.',
        'std'         => '',
        'type'        => 'javascript',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'css',
        'label'       => 'سی اس اس',
        'desc'        => 'کدهای سی اس اس مورد نظر خود را در این باکس درج نمائید.',
        'std'         => '',
        'type'        => 'css',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'script',
        'label'       => 'جاوا اسکریپت',
        'desc'        => 'کدهای جاوا اسکریپت خود را در این باکس درج نمائید.',
        'std'         => '',
        'type'        => 'javascript',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'banner_popup',
        'label'       => 'بنر پاپ آپ',
        'desc'        => '',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'link_popup',
        'label'       => 'بنر پاپ آپ',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'general',
        'operator'    => 'and'
      ),
	  /************************************ HEADER *************************************/
	  array(
        'id'          => 'logo',
        'label'       => 'لوگو',
        'desc'        => 'لوگوی مورد نظر خود را با عرض 220 پیکسل و ارتفاع 90 پیکسل آپلود نمائید.',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'header',
      ), 
	  /*
      array(
        'id'          => 'responsive_menu',
        'label'       => 'محدوده نمایش منوی ریسپانسیو',
        'desc'        => 'محدوده ای را که مایل هستید منو به صورت ریسپانسیو نمایش داده شود را به پیکسل انتخاب نمائید.',
        'std'         => '800',
        'type'        => 'numeric-slider',
        'section'     => 'header',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '320,1170',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  */
   	 array(
		 'id'          => 'quick_links',
		 'label'       => 'لینک های بالای صفحات سمت راست',
		 'desc'        => 'در اینجا میتوانید لینک های دلخواه خود را در بالای صفحات به همراه آیکون قرار دهید.',
		 'std'         => '',
		 'type'        => 'list-item',
		 'section'     => 'header',
		 'settings'  => array(
		 	array(
				 'id'        => 'link',
				 'label'     => 'لینک',
				 'type'      => 'text',
			 ),
			 array(
				 'id'        => 'image',
				 'label'     => 'آیکون',
				 'type'      => 'upload',
			 ),
		 ),
	   ),	
   	 array(
		 'id'          => 'quick_links_left',
		 'label'       => 'لینک های بالای صفحات سمت چپ',
		 'desc'        => 'در اینجا میتوانید لینک های دلخواه خود را در بالای صفحات به همراه آیکون قرار دهید.',
		 'std'         => '',
		 'type'        => 'list-item',
		 'section'     => 'header',
		 'settings'  => array(
		 	array(
				 'id'        => 'link',
				 'label'     => 'لینک',
				 'type'      => 'text',
			 ),
			 array(
				 'id'        => 'image',
				 'label'     => 'آیکون',
				 'type'      => 'upload',
			 ),
		 ),
	   ),	   
	  	  /****************************************** sidebar  *********************************************/	
  	 
	  /****************************************** index *********************************************/
   	 array(
		 'id'          => 'banners_top_index',
		 'label'       => 'بنرهای صفحه اصلی',
		 'desc'        => 'بنرهای خود را با عرض 1170 پیکسل و ارتفاع دلخواه آپلود کنید.',
		 'std'         => '',
		 'type'        => 'list-item',
		 'section'     => 'index',
		 'settings'  => array(
		 	array(
				 'id'        => 'link',
				 'label'     => 'لینک',
				 'type'      => 'text',
			 ),
			 array(
				 'id'        => 'banner',
				 'label'     => 'بنر',
				 'type'      => 'upload',
			 ),
		 ),
	   ),    
   	 array(
		 'id'          => 'short_link_by_icons',
		 'label'       => 'لینک های کوتاه صفحه اصلی همراه با آیکون',
		 'desc'        => '',
		 'std'         => '',
		 'type'        => 'list-item',
		 'section'     => 'index',
		 'settings'  => array(
		 	array(
				 'id'        => 'link',
				 'label'     => 'لینک',
				 'type'      => 'text',
			 ),
			 array(
				 'id'        => 'icon',
				 'label'     => 'آیکون',
				 'type'      => 'upload',
			 ),
		 ),
	   ),	   
	  array(
        'id'          => 'layout_sidebar_content',
        'label'       => 'جایگاه سایدبار',
        'desc'        => 'جایگاه سایدبار صفحه اصلی را مشخص نمائید.',
        'std'         => 'سایدبار راست',
        'type'        => 'radio-image',
        'section'     => 'index',
        'operator'    => 'and'
      ),
  array( 
        'id'          => 'page_index',
        'label'       => 'برگه درباره ما',
        'desc'        => 'برگه ای را که مایل هستید در باکس درباره ما نمایش داده شود را انتخاب نمائید.',
        'std'         => '',
        'type'        => 'page-select',
        'section'     => 'index',
      ),
   	 array(
		 'id'          => 'slider',
		 'label'       => 'اسلایدر صفحه اصلی',
		 'desc'        => '',
		 'std'         => '',
		 'type'        => 'list-item',
		 'section'     => 'index',
		 'settings'  => array(
		 	array(
				 'id'        => 'link',
				 'label'     => 'لینک',
				 'type'      => 'text',
			 ),
			 array(
				 'id'        => 'banner',
				 'label'     => '',
				 'type'      => 'upload',
			 ),
		 ),
	   ),
	   
   	 array(
		 'id'          => 'banners_index',
		 'label'       => 'بنرهای صفحه اصلی',
		 'desc'        => 'این بنر ها در زیر اسلایدر تخفیفات صفحه اصلی نمایش داده خواهد شد<br> عرض بنر ها را یا 570 پیکسل و یا 280 پیکسل و با ارتفاع 190 پیکسل درج نمائید.',
		 'std'         => '',
		 'type'        => 'list-item',
		 'section'     => 'index',
		 'settings'  => array(
		 	array(
				 'id'        => 'link',
				 'label'     => 'لینک',
				 'type'      => 'text',
			 ),
		 	array(
				 'id'        => 'type_banner',
				 'label'     => 'مشخص کنید که این بنر شما در این آیتم چه عرضی دارد.',
				 'type'      => 'radio',
				 'std'         => 'small_banner',
				'choices'     => array( 
				  array(
					'value'       => 'large_banner',
					'label'       => 'بنر با عرض 570 پیکسل',
					'src'         => ''
				  ),
				  array(
					'value'       => 'small_banner',
					'label'       => 'بنر با عرض 280 پیکسل',
					'src'         => ''
				  ),
				)
			 ),
			 array(
				 'id'        => 'banner',
				 'label'     => 'تصویر بنر',
				 'type'      => 'upload',
			 ),
		 ),
	   ),	   
	   
 
 array( 
        'id'          => 'about_us',
        'label'       => 'برگه درباره ما',
        'desc'        => 'برگه ای را که مایل هستید در باکس درباره ما نمایش داده شود را انتخاب نمائید.',
        'std'         => '',
        'type'        => 'page-select',
        'section'     => 'index',
      ),
	 
 array( 
        'id'          => 'num_post_product_widget',
        'label'       => 'تعداد مطالب باکس های صفحه اصلی',
        'desc'        => 'تعداد مطالبی را که مایل هستید در باکس های صفحه اصلی نمایش داده شود را انتخاب نمائید.',
        'std'         => '10',
        'type'        => 'numeric-slider',
        'section'     => 'index',
		'min_max_step'=>  '1,20',
      ),

 array( 
        'id'          => 'cats_index_product',
        'label'       => 'آخرین محصولات',
        'desc'        => 'دسته هایی را که مایل هستید آخرین محصولات آن در باکس آخرین محصولات نمایش داده شود را انتخاب نمائید.',
        'std'         => '',
        'type'        => 'taxonomy-checkbox',
        'section'     => 'index',
		'taxonomy'    => 'product_cat',
      ),
 	 array( 
        'id'          => 'num_post_product',
        'label'       => 'آخرین محصولات',
        'desc'        => 'تعداد مطالبی را که مایل هستید در باکس آخرین محصولات نمایش داده شود را به عدد وارد نمائید.',
        'std'         => '10',
        'type'        => 'numeric-slider',
        'section'     => 'index',
		'min_max_step'=>  '1,30',
      ),
 array( 
        'id'          => 'cats_index_product_sliders',
        'label'       => 'دسته های صفحه اصلی',
        'desc'        => '',
        'std'         => '',
        'type'        => 'taxonomy-checkbox',
        'section'     => 'index',
		'taxonomy'    => 'product_cat',
      ),
 	 array( 
        'id'          => 'num_post_product_sliders_cat',
        'label'       => 'تعداد مطالب اسلایدرهای صفحه اصلی',
        'desc'        => '',
        'std'         => '10',
        'type'        => 'numeric-slider',
        'section'     => 'index',
		'min_max_step'=>  '1,30',
      ),
 	 array( 
        'id'          => 'autoPlay_slider',
        'label'       => 'اسلاید اتوماتیک اسلایدرهای صفحه اصلی',
        'desc'        => 'در صورتی که مایل هستید اسلایدرهای صفحه اصلی به صورت اتوماتیک اسلاید داشته باشند این گزینه رو فعال کنید.',
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'index',
      ),
	  /******************************************  sidebar index *********************************************/	

 	 array( 
        'id'          => 'show_box_featured_sidebar',
        'label'       => 'نمایش باکس محصولات ویژه در سایدبار',
        'desc'        => '',
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'sidebar-index',
      ),
 	 array( 
        'id'          => 'show_box_average_rating_sidebar',
        'label'       => 'نمایش باکس محبوبترین محصولات در سایدبار',
        'desc'        => '',
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'sidebar-index',
      ),
 	 array( 
        'id'          => 'show_box_total_sales_sidebar',
        'label'       => 'نمایش باکس پرفروش ترین محصولات در سایدبار',
        'desc'        => '',
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'sidebar-index',
      ),
	  
	  /******************************************  footer *********************************************/	
	array( 
        'id'          => 'footer_slogan',
        'label'       => 'شعار فوتر',
        'desc'       => 'شعاری را که مایل هستید در فوتر نمایش داده شود را به صورت مختصر در این فیلد درج نمائید.',
        'type'        => 'text',
        'section'     => 'footer',
      ),
   	 array(
		 'id'          => 'quick_links_left_footer',
		 'label'       => 'لینک های بالای صفحات سمت چپ',
		 'desc'        => 'در اینجا میتوانید لینک های دلخواه خود را در بالای صفحات به همراه آیکون قرار دهید.',
		 'std'         => '',
		 'type'        => 'list-item',
		 'section'     => 'footer',
		 'settings'  => array(
			 array(
				 'id'        => 'image',
				 'label'     => 'آیکون',
				 'type'      => 'upload',
			 ),
		 ),
	   ),
	  array( 
        'id'          => 'about_us_footer',
        'label'       => 'درباره ما فروشگاه',
        'desc'       => 'توضیحات مورد نظر فروشگاه را در این ادیتور درج نمائید.',
        'type'        => 'textarea',
        'section'     => 'footer',
      ),	   
	  array( 
        'id'          => 'banner_footer',
        'label'       => 'بنر فوتر',
        'desc'       => 'در صورتی که میخواهید بنر فوتر را تعویض نمائید یک بنر با عرض و ارتفاع 82*1140 پیکسل آپلود نمائید.',
        'type'        => 'upload',
        'section'     => 'footer',
      ),
   	 array(
		 'id'          => 'logos_offices',
		 'label'       => 'کدهای جاوااسکریپت اینماد ، ساماندهی و مابقی رو در این قسمت قرار دهید. در هر آیتم یک لوگو رو قرار دهید.',
		 'desc'        => '',
		 'std'         => '',
		 'type'        => 'list-item',
		 'section'     => 'footer',
		 'settings'  => array(
			 array(
				 'id'        => 'code',
				 'label'     => 'کد جاوااسکریپت',
				 'type'      => 'textarea',
			 ),
		 ),
	   ),	  
       array( 
        'id'          => 'enamad',
        'label'       => 'کد اینماد',
        'desc'       => 'کد آی فریم اینماد خود را در این باکس درج نمائید.',
        'type'        => 'textarea-simple',
        'section'     => 'footer',
      ),
	  array( 
        'id'          => 'address',
        'label'       => 'آدرس',
        'desc'       => 'آدرس مورد نظر را در این فیلد وارد نمائید.',
        'type'        => 'text',
        'section'     => 'footer',
      ),
 array( 
        'id'          => 'phone',
        'label'       => 'تلفن',
        'desc'       => 'تلفن مورد نظر را در این فیلد وارد نمائید.',
        'type'        => 'text',
        'section'     => 'footer',
      ),
 array( 
        'id'          => 'mail',
        'label'       => 'پست الکترونیک',
        'desc'       => 'ایمیل مورد نظر را در این فیلد وارد نمائید.',
        'type'        => 'text',
        'section'     => 'footer',
      ),
array( 
        'id'          => 'page_footer',
        'label'       => 'خدمات مشتریان',
        'desc'       => 'برگه هایی را که مایل هستید در باکس خدمات مشتریان نمایش داده شود را انتخاب نمائید.',
        'type'        => 'page-checkbox',
        'section'     => 'footer',
      ),
	   array( 
        'id'          => 'newsletter_shortcode',
        'label'       => 'شورت کد خبرنامه',
        'desc'       => 'شورت کد خبرنامه را در این فیلد درج نمائید.',
        'type'        => 'text',
        'section'     => 'footer',
      ),
	   array( 
        'id'          => 'facebook_page',
        'label'       => 'کانال تلگرام',
        'desc'       => 'آدرس مورد نظر را در این فیلد وارد نمائید.',
        'type'        => 'text',
        'section'     => 'footer',
      ),
	   array( 
        'id'          => 'gplus_page',
        'label'       => 'صفحه آپارات',
        'desc'       => 'آدرس مورد نظر را در این فیلد وارد نمائید.',
        'type'        => 'text',
        'section'     => 'footer',
      ),
	   array( 
        'id'          => 'linkdin_page',
        'label'       => 'صفحه اینستاگرام',
        'desc'       => 'آدرس مورد نظر را در این فیلد وارد نمائید.',
        'type'        => 'text',
        'section'     => 'footer',
      ),
	   array( 
        'id'          => 'youtube_page',
        'label'       => 'صفحه لنزور',
        'desc'       => 'آدرس مورد نظر را در این فیلد وارد نمائید.',
        'type'        => 'text',
        'section'     => 'footer',
      ),
 array( 
        'id'          => 'copyright',
        'label'       => 'کپی رایت',
        'desc'       => 'کپی رایت خود را در این باکس درج نمائید.',
        'type'        => 'textarea',
        'section'     => 'footer',
      ),
	  
	  /****************************************** single *********************************************/  
  array( 
        'id'          => 'direction_gallery',
        'label'       => 'نمایش تصویر شاخص محصول',
		'desc'       => 'در صورتی که تصویر شاخص محصول در صفحه محصول نمایش داده نمیشود تیک این گزینه را بزنید.',
        'type'        => 'checkbox',
        'std'        => '',
        'section'     => 'single',
		'choices'     => array( 
          array(
            'value'       => 'Yes',
            'label'       => 'نمایش تصویر محصول در صفحه محصول',
            'src'         => ''
          )
        )
      ),
  array( 
        'id'          => 'layout_single_onliner',
        'label'       => 'نحوه نمایش باکس های صفحه محصول رو انتخاب کنید',
		'desc'       => 'میتوانید این صفحه را به صورت تب منو یا اسکرول خور انتخاب نمائید.',
        'type'        => 'radio',
        'std'        => 'scroll',
        'section'     => 'single',
		'choices'     => array( 
          array(
            'value'       => 'scroll',
            'label'       => 'به صورت اسکرول و تمامی باکس ها زیر هم',
            'src'         => ''
          ),
          array(
            'value'       => 'tabmenu',
            'label'       => 'به صورت تب منوی پیشفرض ووکامرس',
            'src'         => ''
          )
        )
      ),
	array(
            'id'          => 'layout_single_product',
            'label'       => 'چیدمان باکس های صفحه نمایش محصول',
            'desc'        => 'در صورتی که فیلد بالا رو به صورت اسکرول خور انتخاب کرده اید میتوانید نحوه چینش باکس ها رو از اینجا تغییر بدید',
            'std'         => array( 
				array('title' => 'جزئیات و گالری محصول' , 'name_box' => 'summary'),
				array('title' => 'توضیحات کوتاه محصول' , 'name_box' => 'excerpt'),
				array('title' => 'مشخصات محصول' , 'name_box' => 'attributes'),
				array('title' => 'توضیحات کامل محصول' , 'name_box' => 'content'),
				array('title' => 'محصولات پیشنهادی' , 'name_box' => 'upsell'),
				array('title' => 'محصولات مرتبط' , 'name_box' => 'related'),
				array('title' => 'دیدگاه ها محصول' , 'name_box' => 'comments-product')
			 ),
            'type'        => 'list-item',
            'section'     => 'single',
            'settings'  => array(
                array(
                    'id'        => 'name_box',
                    'label'     => 'نوع باکس',
                    'type'      => 'select',
            'choices'     => array(  
                array(
                'value'       => 'summary',
                'label'       => 'جزئیات و گالری محصول',
                'src'         => ''
                ),
                array(
                'value'       => 'excerpt',
                'label'       => 'توضیحات کوتاه محصول',
                'src'         => ''
                ),
                array(
                'value'       => 'attributes',
                'label'       => 'مشخصات محصول',
                'src'         => ''
                ),
                array(
                'value'       => 'content',
                'label'       => 'توضیحات کامل محصول',
                'src'         => ''
                ),
                array(
                'value'       => 'upsell',
                'label'       => 'محصولات پیشنهادی',
                'src'         => ''
                ),
                array(
                'value'       => 'related',
                'label'       => 'محصولات مرتبط',
                'src'         => ''
                ),
                array(
                'value'       => 'comments-product',
                'label'       => 'دیدگاه ها محصول',
                'src'         => ''
                ),
          )
                ),
            ),   
        ),
  array( 
        'id'          => 'layout_single_product_onliner',
        'label'       => 'نحوه نمایش صفحه محصول را انتخاب کنید',
		'desc'       => 'میتوانید صفحه را به صورت فول عرض یا با سایدبار راست یا چپ انتخاب کنید.',
        'type'        => 'radio',
        'std'        => 'sidebar_right',
        'section'     => 'single',
		'choices'     => array( 
          array(
            'value'       => 'full_width',
            'label'       => 'به صورت تمام عرض',
            'src'         => ''
          ),
          array(
            'value'       => 'sidebar_right',
            'label'       => 'سایدبار سمت راست و محتوا در سمت چپ',
            'src'         => ''
          ),
          array(
            'value'       => 'sidebar_left',
            'label'       => 'سایدبار سمت چپ و محتوا در سمت راست',
            'src'         => ''
          )
        )
      ),
  array( 
        'id'          => 'display_taxonomy_tags_product_in_single_product',
        'label'       => 'نمایش برچسب ها و دسته بندی های محصول',
		'desc'       => 'در صورتی که مایل هستید دسته بندی ها و برچسب های محصول در صفحه محصول نمایش داده نشود دکمه را بر روی حالت on بگذارید
		این مورد فقط برچسب ها و دسته بندی ها رو مخفی میکنه و روی سئو تاثیر منفی نداره.',
        'type'        => 'on-off',
        'std'        => 'off',
        'section'     => 'single',
      ),
 array( 
        'id'          => 'error',
        'label'       => 'خطای 404',
        'type'        => 'textarea',
        'section'     => 'single',
      ),
 	 array( 
        'id'          => 'posts_per_page_related',
        'label'       => 'مطالب مرتبط',
        'desc'        => 'تعداد مطالبی را که مایل هستید در باکس مطالب مرتبط نمایش داده شود را به عدد وارد نمائید.',
        'std'         => '10',
        'type'        => 'numeric-slider',
        'section'     => 'single',
		'min_max_step'=>  '1,20',
      ),	  
	  /******************************************  *********************************************/	
    ),
/******************************************  *********************************************/	
	'sections'        => array( 
      array(
        'id'          => 'general',
        'title'       => 'تنظیمات عمومی'
      ),
	  array(
        'id'          => 'header',
        'title'       => 'تنظیمات هدر'
      ),
	  array(
        'id'          => 'sidebar-index',
        'title'       => 'تنظیمات سایدبار'
      ),
	  array(
        'id'          => 'index',
        'title'       => 'تنظیمات صفحه اصلی'
      ),
	  array(
        'id'          => 'single',
        'title'       => 'صفحه نمایش محصول'
      ),
	  array(
        'id'          => 'footer',
        'title'       => 'تنظیمات فوتر'
      ),	
	  
    ),
/******************************************  *********************************************/	
  );
  
  /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( ot_settings_id() . '_args', $custom_settings );
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( ot_settings_id(), $custom_settings ); 
  }
  
  /* Lets OptionTree know the UI Builder is being overridden */
  global $ot_has_custom_theme_options;
  $ot_has_custom_theme_options = true;
  
}
$template_url = get_bloginfo('template_url');
define('SOURCE' , $template_url);
// add_action('admin_init', 'add_meta_boxes', 1);
// function add_meta_boxes() {
	// add_meta_box( 'repeatable-fields', 'تخفیفات زمان دار', 'meta_box_display', 'product', 'normal', 'high');
// }
// function meta_box_display() {
	// global $post;
	// $post_id_feauchers = get_option('post_id_feauchers');
	// echo '<label><input ';
	// if ( @in_array( $post->ID , $post_id_feauchers ) ) { echo 'checked="checked"'; } 
	// echo 'type="checkbox" name="show_in_feauchers" value="show_in_feauchers" />نمایش این محصول در اسلایدر تخفیفات زمان دار</label>';
	// $content_slider = get_post_meta( $post->ID , 'content_slider', true);
	// echo '<br><br>محتوایی را که مایل هستید در اسلایدر تخفیفات نمایش داده شود را به صورت مختصر در این باکس درج نمائید. <br>
	// <textarea style="width:100%" name="content_slider">'.$content_slider.'</textarea>';
// }
// add_action('save_post', 'meta_box_save');
// function meta_box_save($post_id) {
	// global $post;
	// $post_id_feauchers = get_option('post_id_feauchers');
	// if(!$post_id_feauchers){$post_id_feauchers=array(); }
	// if ( isset($_POST['show_in_feauchers']) ) {
		// if (! @in_array( $post->ID , $post_id_feauchers ) ) {
		// $post_id_feauchers[] = $post->ID ;
		// update_option( 'post_id_feauchers', $post_id_feauchers);
		// }
	// } else {
		// $arr = @array_diff($post_id_feauchers, array($post->ID));
		// update_option( 'post_id_feauchers', $arr);
	// }	
	// if ( isset($_POST['content_slider']) ) update_post_meta( $post->ID , 'content_slider', $_POST['content_slider'] );
	
// }